| postProb | R Documentation |
Obtain posterior model probabilities after running Bayesian model selection
postProb(object, nmax, method='norm')
object |
Object of class msfit returned by |
nmax |
Maximum number of models to report (defaults to no max) |
method |
Only when |
A data.frame with posterior model probabilities in column pp.
Column modelid indicates the indexes of the selected covariates (empty
for the null model with no covariates)
For msfit_ggm objects, a list with posterior probabilities
(element "pp") and the corresponding model (element "modelid")
indicating what edges are non-zero
For mixturebf objects, posterior probabilities for the
specified number of components
For localtest objects, posterior probabilities of a local covariate
effect at various regions
David Rossell
modelSelection to perform model selection
#See help(modelSelection)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.